@@ -771,7 +771,7 @@ class create_random_permute(torch.nn.Module):
 def inverse(input: VSATensor) -> VSATensor:
     r"""Inverse for the binding operation.
 
-    See :func:`~torchhd.functional.bind`.
+    See :func:`~torchhd.bind`.
 
     Args:
         input (VSATensor): input hypervector
@@ -796,7 +796,7 @@ def inverse(input: VSATensor) -> VSATensor:
 def negative(input: VSATensor) -> VSATensor:
     r"""Inverse for the bundling operation.
 
-    See :func:`~torchhd.functional.bundle`.
+    See :func:`~torchhd.bundle`.
 
     Args:
         input (VSATensor): input hypervector
@@ -1221,7 +1221,7 @@ def ngrams(input: VSATensor, n: int = 3) -> VSATensor:
         \bigoplus_{i=0}^{m - n} \bigotimes_{j = 0}^{n - 1} \Pi^{n - j - 1}(V_{i + j})
 
     .. note::
-        For :math:`n=1` use :func:`~torchhd.functional.multiset` instead and for :math:`n=m` use :func:`~torchhd.functional.bind_sequence` instead.
+        For :math:`n=1` use :func:`~torchhd.multiset` instead and for :math:`n=m` use :func:`~torchhd.bind_sequence` instead.
 
     Args:
         input (VSATensor): The value hypervectors.
